'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _createReactClass = require('create-react-class');

var _createReactClass2 = _interopRequireDefault(_createReactClass);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactRedux = require('react-redux');

var _Dialog = require('./templates/Dialog');

var _Dialog2 = _interopRequireDefault(_Dialog);

var _Modal = require('./templates/Modal');

var _Modal2 = _interopRequireDefault(_Modal);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// templates
exports.default = {

  /**
   * DOM Element ID that the dialogs should be mounted to. Should be located
   * outside the DOM element the application is mounted to.
   */

  domElementId: 'dialog',

  /**
   * The different types of dialogs that can be shown, each containing the logic
   * to show and hide a dialog. You can extend this set to includes alerts, full-screen
   * dialogs, scrollable dialogs, modal dialogs, etc.
   */

  templates: {
    dialog: _Dialog2.default,
    modal: _Modal2.default
  },

  /**
   * The default template that should be used
   */

  defaultTemplate: 'dialog',

  /*
   * Container that wraps all dialogs. Primary purpose is to provide data through
   * context, so components behave like you would expect.
   *
   * The default configuration wraps dialogs with Provider so that lore.connect
   * will work. If you need additional functionality, such as routing and
   * access to the current user, you'll need to define 'lore.dialog.childContextTypes'
   * and 'lore.dialog.getChildContext' *before* calling 'lore.dialog.show'.
   *
   * A good place to do this is in the 'Master' component, by setting those
   * values inside the 'getChildContext' of that component.
   */

  buildDialogContainer: function buildDialogContainer(lore) {
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var store = lore.store;
    var _lore$config$dialog = lore.config.dialog,
        templates = _lore$config$dialog.templates,
        defaultTemplate = _lore$config$dialog.defaultTemplate;

    var Dialog = templates[options.template || defaultTemplate];

    var childContextTypes = options.childContextTypes || lore.dialog.childContextTypes || {};

    var getChildContext = options.getChildContext || lore.dialog.getChildContext || function () {
      return {};
    };

    return (0, _createReactClass2.default)({
      displayName: 'DialogContainer',

      propTypes: {
        dialog: _propTypes2.default.object.isRequired
      },

      childContextTypes: childContextTypes,

      getChildContext: getChildContext,

      render: function render() {
        var dialog = this.props.dialog;


        return _react2.default.createElement(
          _reactRedux.Provider,
          { store: store },
          _react2.default.createElement(Dialog, { dialog: dialog })
        );
      }
    });
  },

  /*
   * The function responsible for mounting the dialog once it's been created.
   *
   * By default, the previous dialog is unmounted *only* when mounting a new
   * dialog. This means previous dialogs may still"in the background"; invisible
   * but still mounted to the DOM.
   *
   * Before mounting a new dialog, we unmount the previous one (if it exists) to
   * make sure we have a clean canvas to work with, and so that no component state
   * will carry over (such as when launching the same dialog back-to-back).
   */

  renderDialogToDom: function renderDialogToDom(domElementId, component) {
    // Get the DOM node we should mount the dialog to
    var node = document.getElementById(domElementId);

    // Umnount any dialog previously mounted to this DOM node
    _reactDom2.default.unmountComponentAtNode(node);

    // Render the dialog to the screen!
    _reactDom2.default.render(component, node);
  }

}; /* eslint no-param-reassign: "off" */